@@ -11,6 +11,9 @@ then
   exit 0
 fi
 
+#default configuration
+[ -f /etc/default/bridge-utils ] && . /etc/default/bridge-utils
+
 . /lib/bridge-utils/bridge-utils.sh
 
 case "$IF_BRIDGE_PORTS" in
@@ -83,33 +86,32 @@ do
     # We attach and configure each port of the bridge
     if [ "$MODE" = "start" ] && [ ! -d /sys/class/net/$IFACE/brif/$port ]; then
       create_vlan_port
-      if [ "$IF_BRIDGE_HW" ]
+      if [ -e "/sys/class/net/$port" ]
       then
-        KVER="$(uname -r)"
-        LKVER="${KVER#*.}"
-        LKVER="${LKVER%%-*}"
-        LKVER="${LKVER%%.*}"
-        if [ "${KVER%%.*}" -lt 3 -o "${KVER%%.*}" -eq 3 -a "$LKVER" -lt 3 ]
+        if [ "$IF_BRIDGE_HW" ]
         then
-          ip link set dev $port address $IF_BRIDGE_HW
+          KVER="$(uname -r)"
+          LKVER="${KVER#*.}"
+          LKVER="${LKVER%%-*}"
+          LKVER="${LKVER%%.*}"
+          if [ "${KVER%%.*}" -lt 3 -o "${KVER%%.*}" -eq 3 -a "$LKVER" -lt 3 ]
+          then
+            ip link set dev $port address $IF_BRIDGE_HW
+          fi
         fi
+        if [ -e /proc/sys/net/ipv6/conf/$port ]
+        then
+          ip link set $port addrgenmode none
+        fi
+        if [ "$IF_MTU" ]
+        then
+          ip link set dev $port mtu "$IF_MTU"
+        fi
+        brctl addif $IFACE $port && ip link set dev $port up
       fi
-      if [ -f /proc/sys/net/ipv6/conf/$port/disable_ipv6 ]
-      then
-        echo 1 > /proc/sys/net/ipv6/conf/$port/disable_ipv6
-      fi
-      if [ "$IF_MTU" ]
-      then
-        ip link set dev $port mtu "$IF_MTU"
-      fi
-      brctl addif $IFACE $port && ip link set dev $port up
     # We detach each port of the bridge
     elif [ "$MODE" = "stop" -a "$PHASE" = "post-down" ] && [ -d /sys/class/net/$IFACE/brif/$port ];  then
       ip link set dev $port down && brctl delif $IFACE $port && destroy_vlan_port
-      if [ -f /proc/sys/net/ipv6/conf/$port/disable_ipv6 ]
-      then
-        echo 0 > /proc/sys/net/ipv6/conf/$port/disable_ipv6
-      fi
     fi
   done
 done
